@@ -16,12 +16,24 @@ class Subscriber(object):
         self.queue_params = dict(durable=durable)
 
     def amqp_callback(self, channel, method, header, body):
+        self.channel = channel
         try:
             self.callback(json.loads(body))
             channel.basic_ack(delivery_tag=method.delivery_tag)
         except Exception:
             logger.exception('AMQP message callback error')
 
+    def publish(self, routing_key, body):
+        self.channel.basic_publish(
+            exchange=self.exchange,
+            routing_key=routing_key,
+            properties=pika.BasicProperties(
+                content_type='application/json',
+                content_encoding='utf-8',
+            ),
+            body=json.dumps(body)
+        )
+
 
 class Method(Subscriber):
     def amqp_callback(self, channel, method, header, body):
